@@ -1,6 +1,6 @@
 /*
  * twclock:  A world clock implemented with openMotif widgets
- * Copyright (C) 1997-2014 Ted Williams - WA0EIR
+ * Copyright (C) 1997-2017 Ted Williams - WA0EIR
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge. MA 02139, USA.
  * See the COPYING file in this directory.
  *
- * Versions: 3.3 -  Jan 2014
+ * Versions: 3.4 -  Jan 2017
  */
 
 /*
@@ -220,9 +220,10 @@ int main (int argc, char *argv[])
    }
 
    /* Initialize libCW */
-   cw_init( appRes.keyMode, "TWCLOCK", "dummy");
+// TJW printf ("key=%d speed=%d\n", appRes.keyMode, appRes.cwSpeed);
+   cw_init (appRes.keyMode, "TWCLOCK", "dummy");
    cw_set_wpm (appRes.cwSpeed);
-   cw_set_keyMode (PA, "TWCLOCK");
+// TJW printf ("speed %d\n", appRes.cwSpeed);
 
 #if (MAKE_ICON == 1) && (HAVE_X11_XPM_H == 1) && (HAVE_LIBXPM == 1)
    /*
@@ -254,3 +255,9 @@ int main (int argc, char *argv[])
    XtAppMainLoop (app);
    return (0);
 }
+
+
+
+
+
+
