@@ -10,6 +10,7 @@
 #include <stdio.h>
 #include <ctype.h>
 #include <stdlib.h>
+#include <pthread.h>
 
 #include <Xm/Xm.h>
 #include <Xm/Form.h>
@@ -44,11 +45,6 @@
 #define HELP_DIAG   1
 #define CANCEL_BTN  1
 
-/*
- * Work around when Scale widget won't display both Value and Title
- */
-#define SCALE_BUG 0
-
 /*
  * APPLICATION DEFINED RESOURCES
  */
@@ -93,7 +89,7 @@
 
 typedef struct
    {
-      long     tzone;
+      long    tzone;
       int     blink;
       int     beep;
       int     cwID;
@@ -151,3 +147,7 @@ void errCancelCB (Widget , XtPointer, XtPointer);
 void settimer (void);
 
 #endif
+
+
+
+
