@@ -1,6 +1,6 @@
 /*
  * twclockDiags.h - text for Help dialog
- * Copyright (C) 1997->2014 Ted Williams - WA0EIR 
+ * Copyright (C) 1997->2017 Ted Williams - WA0EIR 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge. MA 02139, USA.
  * See COPYING file in this directory.
  *
- * Version: 3.3 - Jan 2014
+ * Version: 3.5 - Jan 2017
  */
 
 char helpText[] = " \n\
@@ -68,7 +68,7 @@ take effect.\n\
    Here are some of the resources you will want to modify. \n\
 \n\
    Twclock.form.call_toggleB.labelString:   your call\n\
-   Twclock.cwString:   de your call\n\
+   Twclock.cwStr:   de your call\n\
 \n\
 See http://www.faqs.org/faqs/x-faq/part2/section-22.html or \n\
 the X manual pages for more information.\n\
